@@ -1,13 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "contacteditorutil.h"
 
-ContactEditorUtil::ContactEditorUtil()
-{
-}
+ContactEditorUtil::ContactEditorUtil() = default;
 
 QString ContactEditorUtil::defaultContact() const
 {
