@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ GrantleePlainTextEditor::GrantleePlainTextEditor(QWidget *parent)
         qCWarning(GRANTLEETHEMEEDITOR_LOG) << "Invalid definition name";
     }
 
-    KSyntaxHighlighting::SyntaxHighlighter *hl = new KSyntaxHighlighting::SyntaxHighlighter(document());
+    auto hl = new KSyntaxHighlighting::SyntaxHighlighter(document());
     hl->setTheme((palette().color(QPalette::Base).lightness() < 128) ? mRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
                                                                      : mRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     hl->setDefinition(def);
@@ -33,9 +33,7 @@ GrantleePlainTextEditor::GrantleePlainTextEditor(QWidget *parent)
     initCompleter();
 }
 
-GrantleePlainTextEditor::~GrantleePlainTextEditor()
-{
-}
+GrantleePlainTextEditor::~GrantleePlainTextEditor() = default;
 
 void GrantleePlainTextEditor::initCompleter()
 {
